@@ -13,7 +13,6 @@ OC.L10N.register(
     "Download" : "Descărcare",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
-    "can edit" : "poate edita",
     "Cancel" : "Anulează",
     "Add" : "Add",
     "First name" : "Prenume",
@@ -21,12 +20,14 @@ OC.L10N.register(
     "Display name" : "Nume afișat",
     "Save" : "Salvează",
     "Close" : "Închide",
+    "Folder" : "Folder",
     "Create" : "Creează",
     "Invalid image" : "Imagine invalidă",
     "Address book" : "Listă de contacte",
     "Name" : "Nume",
     "Title" : "Titlu",
     "Company" : "Companie",
+    "Edit profile" : "Editează profilul",
     "Move" : "Move",
     "No results" : "Niciun rezultat",
     "Pending" : "În așteptare",
@@ -91,9 +92,6 @@ OC.L10N.register(
     "Gender" : "Sex",
     "Female" : "Femeie",
     "Male" : "Bărbat",
-    "Unknown" : "Necunoscut",
-    "Loading contacts …" : "Se încarcă contactele ...",
-    "Loading …" : "Se încarcă…",
-    "Search contacts …" : "Caută contacte ..."
+    "Unknown" : "Necunoscut"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
