@@ -75,7 +75,6 @@ OC.L10N.register(
     "No users or groups" : "无用户或群组",
     "Unable to delete the share" : "无法删除共享",
     "Unable to change permissions" : "无法更改权限",
-    "can edit" : "可编辑",
     "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
     "Import into the {addressbookName} address book" : "导入 {addressbookName} 通讯录",
     "Select local file" : "选择本地文件",
@@ -172,6 +171,7 @@ OC.L10N.register(
     "Go to talk conversation" : "前往对话",
     "View profile" : "查看个人资料",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人资料损坏但已被修复。请查看内容并点击这里以保存它。",
+    "Edit profile" : "编辑简介",
     "Clone contact" : "克隆联系人",
     "Generate QR Code" : "生成二维码",
     "Contact vCard as QR code" : "联系人名片作为二维码",
@@ -378,18 +378,6 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "团队中出现错误。有关更多详情，请查看控制台。",
     "Unable to create team {circleName}" : "无法创建团队 {circleName}",
     "Unable to delete team {circleId}" : "无法删除团队 {circleId}",
-    "Unable to delete contact" : "无法删除联系人",
-    "Loading contacts …" : "正在加载联系人…",
-    "Loading …" : "正在加载…",
-    "General settings" : "一般设置",
-    "(refreshed once per week)" : "（每周刷新）",
-    "{addressbookname} (Disabled)" : "{addressbookname}（已禁用）",
-    "Unique password …" : "唯一密码…",
-    "Search contacts …" : "搜索联系人…",
-    "Invite members to team" : "邀请成员加入团队",
-    "Loading members list …" : "正在加载成员列表…",
-    "Add to {circle}" : "添加到 {circle}",
-    "Select chart …" : "选择图表…",
-    "_Imported %n contact (skipped %d)_::_Imported %n contacts (skipped %d)_" : ["已导入 %n 位联系人（跳过 %d 位）"]
+    "Unable to delete contact" : "无法删除联系人"
 },
 "nplurals=1; plural=0;");
